@@ -66,26 +66,10 @@ from gettext import gettext as _
 
 from turses.utils import encode
 from turses.meta import wrap_exceptions
-from turses.api.base import authorization
+from turses.api.base import get_authorization_tokens
 
 # -- Defaults -----------------------------------------------------------------
 
-# Timelines
-
-HOME_TIMELINE = 'home'
-MENTIONS_TIMELINE = 'mentions'
-FAVORITES_TIMELINE = 'favorites'
-MESSAGES_TIMELINE = 'messages'
-OWN_TWEETS_TIMELINE = 'own_tweets'
-
-DEFAULT_TIMELINES = {
-    HOME_TIMELINE:       True,
-    MENTIONS_TIMELINE:   True,
-    FAVORITES_TIMELINE:  True,
-    MESSAGES_TIMELINE:   True,
-    OWN_TWEETS_TIMELINE: True,
-}
-
 # Key bindings
 
 KEY_BINDINGS = {
@@ -355,6 +339,7 @@ STYLES = {
     'editor_horizontal_align': 'center',
     'editor_vertical_align': 'bottom',
     'url_format': 'display',
+    'statuses_in_user_info': 3,
 }
 
 # Debug
@@ -362,8 +347,13 @@ STYLES = {
 LOGGING_LEVEL = 3
 
 # Twitter
-
 UPDATE_FREQUENCY = 300
+USE_HTTPS = True
+
+TWITTER = {
+  'update_frequency': UPDATE_FREQUENCY,
+  'use_https': USE_HTTPS,
+}
 
 # Environment
 
@@ -371,6 +361,8 @@ HOME = getenv('HOME')
 
 # -- Configuration ------------------------------------------------------------
 
+DEFAULT_SESSION = 'defaults'
+
 # Default config path
 CONFIG_DIR = '.turses'
 CONFIG_PATH = path.join(HOME, CONFIG_DIR)
@@ -426,12 +418,12 @@ class Configuration(object):
         from the command line interface (if any).
         """
         # load defaults
-        self.default_timelines = DEFAULT_TIMELINES
-        self.update_frequency = UPDATE_FREQUENCY
+        self.twitter = TWITTER
         self.key_bindings = KEY_BINDINGS
         self.palette = PALETTE
         self.styles = STYLES
         self.logging_level = LOGGING_LEVEL
+        self.session = DEFAULT_SESSION
 
         # config and token files
         self.config_file = DEFAULT_CONFIG_FILE
@@ -446,24 +438,31 @@ class Configuration(object):
                 mkdir(CONFIG_PATH)
             except:
                 print encode(_('Error creating config directory in %s' % CONFIG_DIR))
-                exit(3)
+                self.exit_with_code(3)
 
     def parse_args(self, cli_args):
         """Interprets the arguments provided by `cli_args`."""
-        # generate config file and exit
-        if cli_args and cli_args.generate_config:
+        if cli_args is None:
+            return
+
+        if cli_args.generate_config:
             self.generate_config_file(config_file=cli_args.generate_config,)
+            self.exit_with_code(0)
 
         # path to configuration file
-        if cli_args and cli_args.config:
+        if cli_args.config:
             self.config_file = cli_args.config
-        elif cli_args and cli_args.account:
+        elif cli_args.account:
             self.config_file = path.join(CONFIG_PATH, '%s.config' % cli_args.account)
 
         # path to token file
-        if cli_args and cli_args.account:
+        if cli_args.account:
             self.token_file = path.join(CONFIG_PATH, '%s.token' % cli_args.account)
 
+        # session
+        if cli_args.session:
+            self.session = cli_args.session
+
         # debug mode
         self.debug = getattr(cli_args, 'debug', False)
 
@@ -484,24 +483,14 @@ class Configuration(object):
         else:
             self.generate_config_file(self.config_file)
 
-    def _add_section_default_timelines(self, conf):
-        # Default timelines
-        if not conf.has_section(SECTION_DEFAULT_TIMELINES):
-            conf.add_section(SECTION_DEFAULT_TIMELINES)
-        for timeline in DEFAULT_TIMELINES:
-            if conf.has_option(SECTION_DEFAULT_TIMELINES, timeline):
-                continue
-            value = str(self.default_timelines[timeline]).lower()
-            conf.set(SECTION_DEFAULT_TIMELINES, timeline, value)
-
     def _add_section_twitter(self, conf):
         # Twitter
         if not conf.has_section(SECTION_TWITTER):
             conf.add_section(SECTION_TWITTER)
-        if conf.has_option(SECTION_TWITTER, 'update_frequency'):
-            return
-        else:
+        if not conf.has_option(SECTION_TWITTER, 'update_frequency'):
             conf.set(SECTION_TWITTER, 'update_frequency', UPDATE_FREQUENCY)
+        if not conf.has_option(SECTION_TWITTER, 'use_https'):
+            conf.set(SECTION_TWITTER, 'use_https', USE_HTTPS)
 
     def _add_section_key_bindings(self, conf):
         # Key bindings
@@ -637,18 +626,16 @@ class Configuration(object):
 
         if not path.isfile(config_file):
             kwargs.update({
-                'on_success': partial(self._config_generation_success, 
+                'on_success': partial(self._config_generation_success,
                                       config_file)
             })
 
         self._generate_config_file(**kwargs)
-        exit(0)
 
     @wrap_exceptions
     def _generate_config_file(self, config_file):
         conf = RawConfigParser()
 
-        self._add_section_default_timelines(conf)
         self._add_section_twitter(conf)
         self._add_section_key_bindings(conf)
         self._add_section_palette(conf)
@@ -663,7 +650,7 @@ class Configuration(object):
 
     def _config_generation_error(self, config_file):
         print encode(_('Unable to generate configuration file in %s')) % config_file
-        exit(2)
+        self.exit_with_code(2)
 
     def generate_token_file(self,
                             token_file,
@@ -686,26 +673,17 @@ class Configuration(object):
         conf = RawConfigParser()
         conf.read(config_file)
 
-        self._parse_default_timelines(conf)
         self._parse_twitter(conf)
         self._parse_key_bindings(conf)
         self._parse_palette(conf)
         self._parse_styles(conf)
         self._parse_debug(conf)
 
-    def _parse_default_timelines(self, conf):
-        for timeline in self.default_timelines:
-            if conf.has_option(SECTION_DEFAULT_TIMELINES, timeline):
-                try:
-                    value = conf.getboolean(SECTION_DEFAULT_TIMELINES,
-                                            timeline)
-                except ValueError:
-                    continue
-                self.default_timelines[timeline] = value
-
     def _parse_twitter(self, conf):
         if conf.has_option(SECTION_TWITTER, 'update_frequency'):
-            self.update_frequency = conf.getint(SECTION_TWITTER, 'update_frequency')
+            self.twitter['update_frequency'] = conf.getint(SECTION_TWITTER, 'update_frequency')
+        if conf.has_option(SECTION_TWITTER, 'use_https'):
+            self.twitter['use_https'] = conf.getboolean(SECTION_TWITTER, 'use_https')
 
     def _parse_key_bindings(self, conf):
         for binding in self.key_bindings:
@@ -736,6 +714,8 @@ class Configuration(object):
                 elif (style == 'url_format' and
                       style in ['shortened', 'original', 'display']):
                     self.styles[style] = conf.get(SECTION_STYLES, style)
+                elif style == 'statuses_in_user_info':
+                    self.styles[style] = conf.getint(SECTION_STYLES, style)
                 else:
                     self.styles[style] = unicode(conf.get(SECTION_STYLES, style),
                                                  'utf-8')
@@ -754,18 +734,27 @@ class Configuration(object):
             self.oauth_token_secret = conf.get(SECTION_TOKEN, 'oauth_token_secret')
 
     def authorize_new_account(self):
-        access_token = authorization()
-        if access_token:
-            self.oauth_token = access_token['oauth_token']
+        access_tokens = get_authorization_tokens()
+        if access_tokens:
+            access_token = access_tokens['oauth_token']
+            access_token_secret = access_tokens['oauth_token_secret']
+
+            self.oauth_token = access_token
             self.generate_token_file(self.token_file,
-                                   access_token['oauth_token'],
-                                   access_token['oauth_token_secret'])
+                                     access_token,
+                                     access_token_secret)
         else:
             # TODO: exit codes
-            exit(2)
+            self.exit_with_code(2)
 
     def reload(self):
         self.parse_config_file(self.config_file)
 
+    def exit_with_code(self, code):
+        """Invoke `sys.exit` with the given status `code`."""
+        # This is here because makes testing exit codes easier
+        exit(code)
+
+
 # configuration singleton
 configuration = Configuration()
