@@ -14,26 +14,17 @@ from tweepy import TweepError
 
 from turses.utils import get_urls
 from turses.meta import async, wrap_exceptions, Observer
-from turses.config import (
-        HOME_TIMELINE,
-        MENTIONS_TIMELINE,
-        FAVORITES_TIMELINE,
-        MESSAGES_TIMELINE,
-        OWN_TWEETS_TIMELINE,
-
-        configuration,
-)
+from turses.config import configuration
 from turses.utils import is_username
 from turses.models import (
-        is_DM,
-        is_valid_status_text,
-        is_valid_search_text,
-        sanitize_username,
+    is_DM,
+    is_valid_status_text,
+    is_valid_search_text,
+    sanitize_username,
 
-        Timeline,
-        TimelineList,
+    Timeline,
 )
-from turses.api.base import AsyncApi
+from turses.session import Session
 
 
 def merge_dicts(*args):
@@ -169,6 +160,8 @@ class KeyHandler(object):
         # User info mode
         #  we remove the user widget and activate timeline mode when
         #  receiving input
+        # TODO: commands for info mode (any other input will transition to
+        # timeline mode)
         if self.controller.is_in_user_info_mode():
             self.controller.timeline_mode()
 
@@ -204,10 +197,11 @@ def has_active_status(func):
     @wraps(func)
     def wrapper(self, *args, **kwargs):
         status = self.timelines.active_status
-        if status != None:
+        if status is not None:
             return func(self, *args, **kwargs)
     return wrapper
 
+
 def has_timelines(func):
     """
     `func` only is executed if there are any timelines.
@@ -250,23 +244,23 @@ class Controller(Observer):
 
     # -- Initialization -------------------------------------------------------
 
-    def __init__(self, ui, api_backend):
+    def __init__(self, ui, api, timelines):
+        # View
         self.ui = ui
+        self.api = api
+        self.timelines = timelines
+
+        # Load session
+        self.session = Session(self.api)
+        self.session.populate(self.timelines)
+
         self.editor = None
 
-        # Model
-        self.timelines = TimelineList()
-        self.timelines.subscribe(self)
-
-        # Mode
+        # Default Mode
         self.mode = self.INFO_MODE
 
-        # API
-        oauth_token = configuration.oauth_token
-        oauth_token_secret = configuration.oauth_token_secret
-        self.api = AsyncApi(api_backend,
-                            access_token_key=oauth_token,
-                            access_token_secret=oauth_token_secret,)
+        # Subscribe to model updates
+        self.timelines.subscribe(self)
 
     def start(self):
         self.main_loop()
@@ -288,14 +282,20 @@ class Controller(Observer):
 
         # initialize the timelines
         self.info_message(_('Initializing timelines'))
-        self.append_default_timelines()
+
+        for timeline in self.timelines:
+            timeline.update()
+            timeline.activate_first()
+
+        self.timeline_mode()
+        self.clear_status()
 
         # Main loop has to be running
         while not getattr(self, 'loop'):
             pass
 
         # update alarm
-        seconds = configuration.update_frequency
+        seconds = configuration.twitter['update_frequency']
         self.loop.set_alarm_in(seconds, self.update_alarm)
 
     def main_loop(self):
@@ -346,7 +346,7 @@ class Controller(Observer):
     def update_alarm(self, *args, **kwargs):
         self.update_all_timelines()
 
-        seconds = configuration.update_frequency
+        seconds = configuration.twitter['update_frequency']
         self.loop.set_alarm_in(seconds, self.update_alarm)
 
     # -- Modes ----------------------------------------------------------------
@@ -434,52 +434,12 @@ class Controller(Observer):
         timeline.update()
         timeline.activate_first()
         self.timelines.append_timeline(timeline)
-        if self.is_in_info_mode():
-            #self.timeline_mode()
-            pass
-
-    @async
-    def append_default_timelines(self):
-        timelines = [
-            HOME_TIMELINE,
-            MENTIONS_TIMELINE,
-            FAVORITES_TIMELINE,
-            MESSAGES_TIMELINE,
-            OWN_TWEETS_TIMELINE,
-        ]
-
-        default_timelines = configuration.default_timelines
-        is_any_default_timeline = any([default_timelines[timeline] for timeline
-                                                                   in timelines])
-
-        if is_any_default_timeline:
-            self.timeline_mode()
-        else:
-            message = _('You don\'t have any default timelines activated')
-            self.info_message(message)
-            return
-
-        default_timeline_append_functions = {
-            HOME_TIMELINE:       self.append_home_timeline,
-            MENTIONS_TIMELINE:   self.append_mentions_timeline,
-            FAVORITES_TIMELINE:  self.append_favorites_timeline,
-            MESSAGES_TIMELINE:   self.append_direct_messages_timeline,
-            OWN_TWEETS_TIMELINE: self.append_own_tweets_timeline,
-        }
-
-        for timeline in timelines:
-            append = default_timeline_append_functions[timeline]
-            if default_timelines[timeline]:
-                append()
-
-        self.timeline_mode()
-        self.clear_status()
 
     def append_home_timeline(self):
         timeline_fetched = partial(self.info_message,
-                                    _('Home timeline fetched'))
+                                   _('Home timeline fetched'))
         timeline_not_fetched = partial(self.error_message,
-                                        _('Failed to fetch home timeline'))
+                                       _('Failed to fetch home timeline'))
 
         self.append_timeline(name=_('tweets'),
                              update_function=self.api.get_home_timeline,
@@ -502,9 +462,9 @@ class Controller(Observer):
 
     def append_own_tweets_timeline(self):
         timeline_fetched = partial(self.info_message,
-                                    _('Your tweets fetched'))
+                                   _('Your tweets fetched'))
         timeline_not_fetched = partial(self.error_message,
-                                        _('Failed to fetch your tweets'))
+                                       _('Failed to fetch your tweets'))
 
         if not hasattr(self, 'user'):
             self.user = self.api.verify_credentials()
@@ -515,9 +475,9 @@ class Controller(Observer):
 
     def append_mentions_timeline(self):
         timeline_fetched = partial(self.info_message,
-                                    _('Mentions fetched'))
+                                   _('Mentions fetched'))
         timeline_not_fetched = partial(self.error_message,
-                                        _('Failed to fetch mentions'))
+                                       _('Failed to fetch mentions'))
 
         self.append_timeline(name=_('mentions'),
                              update_function=self.api.get_mentions,
@@ -526,9 +486,9 @@ class Controller(Observer):
 
     def append_favorites_timeline(self):
         timeline_fetched = partial(self.info_message,
-                                    _('Favorites fetched'))
+                                   _('Favorites fetched'))
         timeline_not_fetched = partial(self.error_message,
-                                        _('Failed to fetch favorites'))
+                                       _('Failed to fetch favorites'))
 
         self.append_timeline(name=_('favorites'),
                              update_function=self.api.get_favorites,
@@ -537,15 +497,16 @@ class Controller(Observer):
 
     def append_direct_messages_timeline(self):
         timeline_fetched = partial(self.info_message,
-                                    _('Messages fetched'))
+                                   _('Messages fetched'))
         timeline_not_fetched = partial(self.error_message,
-                                        _('Failed to fetch messages'))
+                                       _('Failed to fetch messages'))
 
         self.append_timeline(name=_('messages'),
                              update_function=self.api.get_direct_messages,
                              on_error=timeline_not_fetched,
                              on_success=timeline_fetched,)
 
+    @has_active_status
     def append_thread_timeline(self):
         status = self.timelines.active_status
 
@@ -555,17 +516,21 @@ class Controller(Observer):
                                        _('Failed to fetch thread'))
 
         if is_DM(status):
-            self.error_message(_('Doesn\'t look like a public conversation'))
-            return
+            participants = [status.sender_screen_name,
+                            status.recipient_screen_name]
+            name = _('DM thread: %s' % ', '.join(participants))
+            update_function = self.api.get_message_thread
+        else:
+            participants = status.mentioned_usernames
+            author = status.authors_username
+            if author not in participants:
+                participants.insert(0, author)
 
-        participants = status.mentioned_usernames
-        author = status.authors_username
-        if author not in participants:
-            participants.insert(0, author)
+            name = _('thread: %s' % ', '.join(participants))
+            update_function = self.api.get_thread
 
-        name = _('thread: %s' % ', '.join(participants))
         self.append_timeline(name=name,
-                             update_function=self.api.get_thread,
+                             update_function=update_function,
                              update_args=status,
                              on_error=timeline_not_fetched,
                              on_success=timeline_fetched)
@@ -838,6 +803,29 @@ class Controller(Observer):
                         on_success=tweet_sent,
                         on_error=tweet_not_sent,)
 
+    @text_from_editor
+    @has_active_status
+    def reply_handler(self, text):
+        """Handle the post as a tweet of the given `text` replying to the
+        current status."""
+        status = self.timelines.active_status
+
+        self.info_message(_('Sending reply'))
+
+        if not is_valid_status_text(text):
+            # reply was explicitly cancelled or empty text
+            self.info_message(_('Reply canceled'))
+            return
+
+        reply_sent = partial(self.info_message, _('Reply sent'))
+        reply_not_sent = partial(self.error_message, _('Reply not sent'))
+
+        # API call
+        self.api.reply(status=status,
+                       text=text,
+                       on_success=reply_sent,
+                       on_error=reply_not_sent,)
+
     @text_from_editor
     def direct_message_handler(self, username, text):
         """Handle the post as a DM of the given `text` to `username`."""
@@ -981,8 +969,8 @@ class Controller(Observer):
         prompt = _('Search user (no need to prepend it with "@"')
         handler = self.search_user_handler
         editor = self.ui.show_text_editor(prompt=prompt,
-                                 content='',
-                                 done_signal_handler=handler)
+                                          content='',
+                                          done_signal_handler=handler)
         self.editor_mode(editor)
 
     @has_active_status
@@ -1053,7 +1041,7 @@ class Controller(Observer):
         except ValueError:
             pass
 
-        handler = self.tweet_handler
+        handler = self.reply_handler
         editor = self.ui.show_tweet_editor(prompt=_('Reply to %s' % author),
                                            content=' '.join(mentioned),
                                            done_signal_handler=handler)
@@ -1097,8 +1085,7 @@ class Controller(Observer):
             return
 
         author = status.authors_username
-        if (author != self.user.screen_name and
-            status.user != self.user.screen_name):
+        if author != self.user.screen_name and status.user != self.user.screen_name:
             self.error_message(_('You can only delete your own tweets'))
             return
 
@@ -1224,8 +1211,10 @@ class Controller(Observer):
     def user_info(self):
         status = self.timelines.active_status
 
-        user = self.api.get_user(status.authors_username)
-        self.ui.show_user_info(user)
+        username = status.authors_username
+        user = self.api.get_user(username)
+        last_statuses = self.api.get_user_timeline(username)
+        self.ui.show_user_info(user, last_statuses)
         self.user_info_mode(user)
 
     # - Configuration ---------------------------------------------------------
